Index: /issm/trunk/src/m/classes/@bamggeom/bamggeom.m
===================================================================
--- /issm/trunk/src/m/classes/@bamggeom/bamggeom.m	(revision 5092)
+++ /issm/trunk/src/m/classes/@bamggeom/bamggeom.m	(revision 5093)
@@ -17,5 +17,4 @@
 	bg.hVertices=[];
 	bg.MetricVertices=[];
-	bg.h1h2VpVertices=[];
 	bg.SubDomains=[];
 
Index: /issm/trunk/src/m/classes/@bamgmesh/bamgmesh.m
===================================================================
--- /issm/trunk/src/m/classes/@bamgmesh/bamgmesh.m	(revision 5092)
+++ /issm/trunk/src/m/classes/@bamgmesh/bamgmesh.m	(revision 5093)
@@ -12,6 +12,6 @@
 	bm.Triangles=[];
 	bm.Quadrilaterals=[];
-	bm.ElementEdges=[];
-	bm.Segments=[];
+	bm.IssmEdges=[];
+	bm.IssmSegments=[];
 	bm.VerticesOnGeometricVertex=[];
 	bm.VerticesOnGeometricEdge=[];
Index: /issm/trunk/src/m/classes/public/mesh/meshconvert.m
===================================================================
--- /issm/trunk/src/m/classes/public/mesh/meshconvert.m	(revision 5092)
+++ /issm/trunk/src/m/classes/public/mesh/meshconvert.m	(revision 5093)
@@ -31,7 +31,7 @@
 md.y=bamgmesh_out.Vertices(:,2);
 md.elements=bamgmesh_out.Triangles(:,1:3);
-md.edges=bamgmesh_out.ElementEdges;
-md.segments=bamgmesh_out.Segments(:,1:3);
-md.segmentmarkers=bamgmesh_out.Segments(:,4);
+md.edges=bamgmesh_out.IssmEdges;
+md.segments=bamgmesh_out.IssmSegments(:,1:3);
+md.segmentmarkers=bamgmesh_out.IssmSegments(:,4);
 
 %Fill in rest of fields:

Index: /issm/trunk/src/m/classes/public/bamg.m
===================================================================
--- /issm/trunk/src/m/classes/public/bamg.m	(revision 5092)
+++ /issm/trunk/src/m/classes/public/bamg.m	(revision 5093)
@@ -12,5 +12,5 @@
 %
 %   - anisomax    : maximum ration between the smallest and largest edges (default is 10^30)
 %   - coef        : coefficient applied to the metric (2-> twice as many elements, default is 1)
 %   - cutoff      : scalar used to compute the metric when metric type 2 or 3 are applied
 %   - err         : error used to generate the metric from a field
@@ -22,5 +22,5 @@
 %                   1 -> use Green formula
 %   - KeepVertices: try to keep initial vertices when adaptation is done on an existing mesh (default 1)
 %   - MaximalAngleOfCorner: maximal angle of corners in degree (default is 10)
 %   - maxnbv      : maximum number of vertices used to allocate memory (default is 10^6)
 %   - maxsubdiv   : maximum subdivision of exisiting elements (default is 10)
@@ -30,5 +30,5 @@
 %                   3 -> rescaled absolute error c/(err coeff^2) * Abs(H)/(smax-smin)
 %   - nbjacoby    : correction used by Hessiantype=1 (default is 1)
-%   - NbSmooth    : number of metric smoothing procedure (default is 3)
+%   - nbsmooth    : number of metric smoothing procedure (default is 3)
 %   - omega       : relaxation parameter of the smoothing procedure (default is 1.8)
 %   - power       : power applied to the metric (default is 1)
@@ -271,5 +271,5 @@
 bamg_options.Crack=getfieldvalue(options,'Crack',0);
 bamg_options.anisomax=getfieldvalue(options,'anisomax',10^30);
-bamg_options.coef=getfieldvalue(options,'coef',1);
+bamg_options.coeff=getfieldvalue(options,'coeff',1);
 bamg_options.cutoff=getfieldvalue(options,'cutoff',10^-5);
 bamg_options.err=getfieldvalue(options,'err',0.01);
@@ -283,5 +283,5 @@
 bamg_options.hmaxVertices=getfieldvalue(options,'hmaxVertices',[]);
 bamg_options.KeepVertices=getfieldvalue(options,'KeepVertices',1);
-bamg_options.MaximalAngleOfCorner=getfieldvalue(options,'MaximalAngleOfCorner',10);
+bamg_options.MaxCornerAngle=getfieldvalue(options,'MaxCornerAngle',10);
 bamg_options.maxnbv=getfieldvalue(options,'maxnbv',10^6);
 bamg_options.maxsubdiv=getfieldvalue(options,'maxsubdiv',10);
@@ -289,5 +289,5 @@
 bamg_options.Metrictype=getfieldvalue(options,'Metrictype',0);
 bamg_options.nbjacobi=getfieldvalue(options,'nbjacobi',1);
-bamg_options.NbSmooth=getfieldvalue(options,'NbSmooth',3);
+bamg_options.nbsmooth=getfieldvalue(options,'nbsmooth',3);
 bamg_options.omega=getfieldvalue(options,'omega',1.8);
 bamg_options.power=getfieldvalue(options,'power',1);
@@ -307,7 +307,7 @@
 md.y=bamgmesh_out.Vertices(:,2);
 md.elements=bamgmesh_out.Triangles(:,1:3);
-md.edges=bamgmesh_out.ElementEdges;
-md.segments=bamgmesh_out.Segments(:,1:3);
-md.segmentmarkers=bamgmesh_out.Segments(:,4);
+md.edges=bamgmesh_out.IssmEdges;
+md.segments=bamgmesh_out.IssmSegments(:,1:3);
+md.segmentmarkers=bamgmesh_out.IssmSegments(:,4);
 
 %Fill in rest of fields:
@@ -12,5 +12,5 @@
 %
 %   - anisomax    : maximum ration between the smallest and largest edges (default is 10^30)
-%   - coef        : coefficient applied to the metric (2-> twice as many elements, default is 1)
+%   - coeff       : coefficient applied to the metric (2-> twice as many elements, default is 1)
 %   - cutoff      : scalar used to compute the metric when metric type 2 or 3 are applied
 %   - err         : error used to generate the metric from a field
@@ -22,5 +22,5 @@
 %                   1 -> use Green formula
 %   - KeepVertices: try to keep initial vertices when adaptation is done on an existing mesh (default 1)
-%   - MaximalAngleOfCorner: maximal angle of corners in degree (default is 10)
+%   - MaxCornerAngle: maximal angle of corners in degree (default is 10)
 %   - maxnbv      : maximum number of vertices used to allocate memory (default is 10^6)
 %   - maxsubdiv   : maximum subdivision of exisiting elements (default is 10)